@@ -479,9 +479,7 @@ mod_Diagonal_server <- function(id) {
     observeEvent(toListen(), {
       if (input$owndataDIAGONALS == "Yes" && kindExpt_single == "SUDC") {
         showModal(
-          shinyjqui::jqui_draggable(
-            entriesInfoModal_SUDC()
-          )
+          entriesInfoModal_SUDC()
         )
       }
     })
@@ -719,7 +717,7 @@ mod_Diagonal_server <- function(id) {
                         buttons = c('copy', 'excel'),
                         lengthMenu = list(c(10,25,50,-1),
                                           c(10,25,50,"All")))
-      ) %>% 
+      ) |> 
         DT::formatStyle(paste0(rep('V', ncol(df)), 1:ncol(df)),
                         backgroundColor = DT::styleEqual(c(checks),
                                                           colores[1:len_checks]))
@@ -929,9 +927,7 @@ mod_Diagonal_server <- function(id) {
     observeEvent(input$Simulate_Diagonal, {
       req(export_diagonal_design()$final_expt)
       showModal(
-        shinyjqui::jqui_draggable(
-          simuModal_DIAG()
-        )
+        simuModal_DIAG()
       )
     })
     
@@ -953,9 +949,7 @@ mod_Diagonal_server <- function(id) {
         removeModal()
       }else {
         showModal(
-          shinyjqui::jqui_draggable(
-            simuModal_DIAG(failed = TRUE)
-          )
+          simuModal_DIAG(failed = TRUE)
         )
       }
     })
